# Summary
Python library to calculate psychrometric states of moist air.

# Installation
Place either psySI.py or psyIP.py file in your working directory. If you
are working with the international system of units (i.e. SI) then use psySI.py.
If you are are working with imperial units (i.e. IP) then use psyIP.py.

# Description
psypy is a python library that calculates psychrometric states of moist air
using ASHRAE 2009 Fundamentals formulations. Atmospheric  pressure, and two
independent properties must be given to calculate all other state properties.
The state properties include: dry bulb temperature (DBT), specific enthalpy
(H), relative humidity (RH), specific volume (V), humidity ratio (W), and wet
bulb temperature (WBT). Examples can be found in the examples.py file.
